#!/usr/bin/env python3

# [simple carbon project] model SCP-M
# 12 ocean box model calculations (Box 0 - Box 11) plus atmosphere, zonally averaged
# The Australian National University

# O'Neill, C.M. and A. McC. Hogg, M. Ellwood, B.N. Opydke and S.M. Eggins
# The [simple carbon project] v2.0

# Disclaimer: SCP-M comes with no warranty or guarantee, use at your own risk etc 
# (have to say this apparently)


# Data management file for step forward box model
# Data work for various charts and analysis



#Import modules
import math
import numpy as np
import matplotlib.pyplot as plt
import csv




Datadir='Data_files/'


rcp_FFems=np.loadtxt(Datadir+'rcp_FFems.txt')
rcp_LUCems=np.loadtxt(Datadir+'rcp_LUCems.txt')
rcp_SST=np.loadtxt(Datadir+'rcp_SST.txt')
rcp_AtCO2=np.loadtxt(Datadir+'rcp_AtCO2.txt')


rcp_time=rcp_FFems[:,0]
rcp26_FFems=rcp_FFems[:,1]
rcp45_FFems=rcp_FFems[:,2]
rcp60_FFems=rcp_FFems[:,3]
rcp85_FFems=rcp_FFems[:,4]

rcp26_LUCems=rcp_LUCems[:,1]
rcp45_LUCems=rcp_LUCems[:,2]
rcp60_LUCems=rcp_LUCems[:,3]
rcp85_LUCems=rcp_LUCems[:,4]

rcp26_AtCO2=rcp_AtCO2[:,1]
rcp45_AtCO2=rcp_AtCO2[:,2]
rcp60_AtCO2=rcp_AtCO2[:,3]
rcp85_AtCO2=rcp_AtCO2[:,4]

rcp26_SST=rcp_SST[:,1]
rcp45_SST=rcp_SST[:,2]
rcp60_SST=rcp_SST[:,3]
rcp85_SST=rcp_SST[:,4]

# Prepare Anthropocene data
AnthAtCO2=np.loadtxt(Datadir+'Modern_AtCO2Dat.txt')
AnthAtCO2_time=AnthAtCO2[:,0]
AnthAtCO2Dat_AtCO2=AnthAtCO2[:,1]
AnthEmitsDat=np.loadtxt(Datadir+'Hist_AtCO2Ems.txt')
AnthEmitsDat_time=AnthEmitsDat[:,0]
AnthEmitsDat=AnthEmitsDat[:,1]
AnthAtD14C=np.loadtxt(Datadir+'Modern_AtD14CDat.txt') # Includes both Turnbull (2017) NZ data and Stuiver et al (1998) data
AnthAtD14C_time=AnthAtD14C[:,0]
AnthAtD14CDat=AnthAtD14C[:,1]
AnthAtd13C=np.loadtxt(Datadir+'Modern_Atd13CDat.txt')
AnthAtd13C_time=AnthAtd13C[:,0]
AnthAtd13CDat=AnthAtd13C[:,1]

# RCP data
RCP_26_ems=np.loadtxt(Datadir+'RCP_26_ems.txt')
RCP26_time=RCP_26_ems[:,0]
RCP26_CO2ems=RCP_26_ems[:,1]
RCP_45_ems=np.loadtxt(Datadir+'RCP_45_ems.txt')
RCP45_time=RCP_45_ems[:,0]
RCP45_CO2ems=RCP_45_ems[:,1]
RCP_60_ems=np.loadtxt(Datadir+'RCP_60_ems.txt')
RCP60_time=RCP_60_ems[:,0]
RCP60_CO2ems=RCP_60_ems[:,1]
RCP_85_ems=np.loadtxt(Datadir+'RCP_85_ems.txt')
RCP85_time=RCP_85_ems[:,0]
RCP85_CO2ems=RCP_85_ems[:,1]

RCP_26_AtCO2=np.loadtxt(Datadir+'RCP_26_AtCO2.txt')
RCP26_AtCO2=RCP_26_AtCO2[:,1]
RCP_45_AtCO2=np.loadtxt(Datadir+'RCP_45_AtCO2.txt')
RCP45_AtCO2=RCP_45_AtCO2[:,1]
RCP_60_AtCO2=np.loadtxt(Datadir+'RCP_60_AtCO2.txt')
RCP60_AtCO2=RCP_60_AtCO2[:,1]
RCP_85_AtCO2=np.loadtxt(Datadir+'RCP_85_AtCO2.txt')
RCP85_AtCO2=RCP_85_AtCO2[:,1]



# GLODAP data
GLODAP_time=1990
GLODAP_DIC=np.loadtxt(Datadir+'GLODAP_DIC.txt')
GLODAP_Alk=np.loadtxt(Datadir+'GLODAP_Alk.txt')
GLODAP_Phos=np.loadtxt(Datadir+'GLODAP_Phos.txt')
GLODAP_d13C=np.loadtxt(Datadir+'GLODAP_d13C.txt')
GLODAP_D14C=np.loadtxt(Datadir+'GLODAP_d14C.txt')
GLODAP_CO23=np.loadtxt(Datadir+'GLODAP_CO23.txt')

SD_GLODAP_DIC=np.loadtxt(Datadir+'GLODAP_DICSD.txt')
SD_GLODAP_Alk=np.loadtxt(Datadir+'GLODAP_AlkSD.txt')
SD_GLODAP_Phos=np.loadtxt(Datadir+'GLODAP_PhosSD.txt')
SD_GLODAP_d13C=np.loadtxt(Datadir+'GLODAP_d13CSD.txt')
SD_GLODAP_D14C=np.loadtxt(Datadir+'GLODAP_d14CSD.txt')





## Set up of Glacial-interglacial time slices----------------------------------


MIS_SST_slices=np.loadtxt(Datadir+'MIS_SST_slices.txt')
MIS_sal_slices=np.loadtxt(Datadir+'MIS_sal_slices.txt')
MIS_PV11_slices=np.loadtxt(Datadir+'MIS_PV11_slices.txt')
MIS_RCS_atom_slices=np.loadtxt(Datadir+'MIS_RCS_atom_slices.txt')
MIS_TerrBioCPgC_slices=np.loadtxt(Datadir+'MIS_TerrBioCPgC_slices.txt')
MIS_ReefC_slices=np.loadtxt(Datadir+'MIS_ReefC_slices.txt')




